@@ -2,4 +2,4 @@ from .utils import open_url, set_value, click_element, login, check_table_value,
 from .salesforce import get_salesforce_object_records, get_salesforce_object_records_from_query_str, get_object_fields, get_object_field_names
 from .env_msapi import get_datalake_data, get_proxy_api_data, get_datalake_data_from_ex_server
 from .grid import show_grid, show_salesforce_object
-from .pandas_compare import convert_columns, get_diff_df, check_two_df_diff, check_two_excel_diff
+from .pandas_compare import convert_columns, get_diff_df, check_two_excel_diff
