@@ -73,7 +73,6 @@ def save_diff_to_excel(file_name, df_old, df_changed, df_removed, df_added, outp
     # print(df_changed)
     (max_row, max_col) = df_changed.shape
     # print('max_row: {}, max_col:{}'.format(max_row, max_col))
-
     writer = pd.ExcelWriter(file_name)
     df_old.to_excel(writer, "old", index=False, columns=output_columns)
     if max_row > 0:
@@ -101,12 +100,13 @@ def save_diff_to_excel(file_name, df_old, df_changed, df_removed, df_added, outp
     writer.save()
 
 
-def check_two_excel_diff(old_file_name, new_file_name, out_file_name=None, out_dir='./data'):
+def check_two_excel_diff(old_file_name, new_file_name, subset=None, id_key='ID', out_file_name=None, out_dir='./data'):
     old = pd.read_excel(old_file_name, 'Sheet1', na_values=['NA'])
     new = pd.read_excel(new_file_name, 'Sheet1', na_values=['NA'])  # reload from excel
-    subset = old.columns
-    # print(subset)
-    df_changed, df_removed, df_added = get_diff_df(old, new, subset)
+    if not subset:
+        subset = old.columns
+    print(subset)
+    df_changed, df_removed, df_added = get_diff_df(old, new, subset, id_key)
 
     if len(df_changed) == 0 and len(df_removed) == 0 and len(df_added) == 0:
         print('Nothing differece.')
@@ -116,28 +116,9 @@ def check_two_excel_diff(old_file_name, new_file_name, out_file_name=None, out_d
         time_stemp = str(datetime.now())
         time_stemp = time_stemp.replace(':', '_')
         out_file_name = '{}/check_two_excel_diff_{}.xlsx'.format(out_dir, time_stemp)
-    save_diff_to_excel(out_file_name, df_changed, df_removed, df_added, subset)
+    save_diff_to_excel(out_file_name, old, df_changed, df_removed, df_added, subset)
 
     print('Finish: {} changed, {} remvoed, {} added.'.format(len(df_changed), len(df_removed), len(df_added)))
     print('Difference file: ' + out_file_name)
-    return out_file_name
+    return df_changed[subset], df_removed[subset], df_added[subset]
 
-
-def check_two_df_diff(old, new, out_file_name=None, out_dir='./data'):
-    subset = old.columns
-    # print(subset)
-    df_changed, df_removed, df_added = get_diff_df(old, new, subset)
-
-    if len(df_changed) == 0 and len(df_removed) == 0 and len(df_added) == 0:
-        print('Nothing differece.')
-        return
-
-    if out_file_name is None:
-        time_stemp = str(datetime.now())
-        time_stemp = time_stemp.replace(':', '_')
-        out_file_name = '{}/check_two_df_diff_{}.xlsx'.format(out_dir, time_stemp)
-    save_diff_to_excel(out_file_name, df_changed, df_removed, df_added, subset)
-
-    print('Finish: {} changed, {} remvoed, {} added.'.format(len(df_changed), len(df_removed), len(df_added)))
-    print('Difference file: ' + out_file_name)
-    return out_file_name
