@@ -1,10 +1,134 @@
+import time
+import json
+import pandas as pd
+from selenium import webdriver
 from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.common.action_chains import ActionChains
-import pandas as pd
+from xlwings import view
 
-import time
+import configparser
+import cv2
+import numpy as np
+
+import openpyxl
+from openpyxl_image_loader import SheetImageLoader
+
+
+def get_test_df(excel_file, sheet_name='Sheet1'):
+    pxl_doc = openpyxl.load_workbook(excel_file)
+    sheet = pxl_doc[sheet_name]
+    image_loader = SheetImageLoader(sheet)
+    rows = sheet.rows
+    column = {}
+    for cell in next(rows):
+        if not cell.value:
+            continue
+        column[cell.col_idx] = cell.value
+    records = []
+    for row in rows:
+        if not row[0].value:
+            continue
+        record = {}
+        for col_idx in column:
+            cell = next((c for c in row if c.col_idx == col_idx), None)
+            record[column[cell.col_idx]] = cell.value
+            if image_loader.image_in(cell.coordinate):
+                image_file = f'icons/{cell.coordinate}.png'
+                image = image_loader.get(cell.coordinate)
+                image.save(image_file)
+                record[column[cell.col_idx]] = image_file
+        records.append(record)
+    return pd.DataFrame(records)
+
+
+def convert_config_to_json(default_param):
+    config = configparser.ConfigParser()
+    config.read_string(f'[param]\n{default_param}')
+    result = {}
+    for name, value in config.items('param'):
+        result[name] = value
+    return result
+
+
+func_map = {
+    'Login': 'login',
+    'OpenUrl': 'open_url',
+    'Click': 'click_element',
+    'SetValue': 'set_value',
+    'GetData': 'get_table_data'
+}
+
+
+def set_driver(driver_path):
+    chrome_options = webdriver.ChromeOptions()
+    prefs = {"profile.default_content_setting_values.notifications": 2}
+    chrome_options.add_experimental_option("prefs", prefs)
+    driver = webdriver.Chrome(driver_path, chrome_options=chrome_options)
+    return driver
+
+
+def run_case(df, driver):
+    result = df.to_json(orient="records", force_ascii=False)
+    test_case_script_steps = json.loads(result)
+
+    for step in test_case_script_steps:
+        if not step['Action']:
+            continue
+        print(step['Description'])
+        func_name = func_map[step['Action']]
+        default_param = convert_config_to_json(step['DefaultParam']) if step['DefaultParam'] else {}
+        if func_name == 'login':
+            login(driver, default_param['username'], default_param['password'])
+        elif func_name == 'open_url':
+            print(default_param['url'])
+            open_url(driver, default_param['url'])
+        elif func_name == 'click_element':
+            if 'icons/' in step['Anchor']:
+                template = cv2.imread(step['Anchor'], 0)
+                w, h = template.shape[::-1]
+
+                x = 0
+                y = 0
+                try_count = 0
+                while x == 0 or try_count < 3:
+                    try_count = try_count + 1
+                    driver.save_screenshot("screenshot.png")
+                    img = cv2.imread('screenshot.png')
+                    img_gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
+                    res = cv2.matchTemplate(img_gray, template, cv2.TM_CCOEFF_NORMED)
+                    threshold = 0.95
+                    loc = np.where(res >= threshold)
+                    x = 0
+                    y = 0
+                    for pt in zip(*loc[::-1]):
+                        x = pt[0]
+                        y = pt[1]
+                        break
+
+                if x > 0 and y > 0:
+                    actions = ActionChains(driver)  # initialize ActionChain object
+                    i_element = driver.find_element_by_xpath("//div[@class='slds-icon-waffle']");
+                    actions.move_to_element(i_element)
+                    actions.perform()
+
+                    actions.move_by_offset(x / 2 - i_element.location['x'], y / 2 - i_element.location['y'])
+                    actions.click()
+                    actions.perform()
+            else:
+                click_element(driver, step['Anchor'], step['AdditionalAnchor'])
+        elif func_name == 'set_value':
+            label = step['Anchor']
+            value = default_param['value'] if isinstance(default_param, dict) else default_param
+            anchor_type = default_param['input_type'] if isinstance(default_param, dict) else ''
+            print(anchor_type)
+            set_value(driver, label, value, anchor_type)
+        elif func_name == 'get_table_data':
+            column_names = list(step['Anchor'].split('、'))
+            print(column_names)
+            table_df = get_table_data(driver, column_names)
+            view(table_df)
 
 
 def find_elements_by_text(driver, text, tag_name=''):
@@ -127,6 +251,7 @@ def set_value(web_driver, label_text, value, anchor_type=''):
             select_input_element.send_keys(Keys.RETURN)
             click_element(web_driver, value, '')
         if 'lookup' in anchor_type:  # lookup
+            web_driver.implicitly_wait(1)
             select_input_elements = find_elements_by_text(web_driver, 'Search...')
             print('input elements count: {0}'.format(len(select_input_elements)))
             select_input_element = find_max_probability_element(select_input_elements, label_element)
